@@ -153,13 +153,14 @@ position_popup (GnomeDateEdit *gde)
 {
 	gint x, y;
 	gint bwidth, bheight;
+	GtkRequisition requisition;
 
-	gtk_widget_size_request (gde->cal_popup, &gde->cal_popup->requisition);
+	gtk_widget_size_request (gde->cal_popup, &requisition);
 
 	gdk_window_get_origin (gde->date_button->window, &x, &y);
 	gdk_window_get_size (gde->date_button->window, &bwidth, &bheight);
 
-	x += bwidth - gde->cal_popup->requisition.width;
+	x += bwidth - requisition.width;
 	y += bheight;
 
 	if (x < 0)
@@ -174,13 +175,16 @@ position_popup (GnomeDateEdit *gde)
 static void
 select_clicked (GtkWidget *widget, GnomeDateEdit *gde)
 {
-	struct tm mtm;
+	struct tm mtm = {0};
 	GdkCursor *cursor;
 
         /* This code is pretty much just copied from gtk_date_edit_get_date */
       	sscanf (gtk_entry_get_text (GTK_ENTRY (gde->date_entry)), "%d/%d/%d",
 		&mtm.tm_mon, &mtm.tm_mday, &mtm.tm_year); /* FIXME: internationalize this - strptime()*/
-        
+
+	mtm.tm_mon = CLAMP (mtm.tm_mon, 1, 12);
+	mtm.tm_mday = CLAMP (mtm.tm_mday, 1, 31);
+
         mtm.tm_mon--;
 
 	/* Hope the user does not actually mean years early in the A.D. days...
@@ -578,6 +582,9 @@ gnome_date_edit_get_date (GnomeDateEdit *gde)
 	sscanf (gtk_entry_get_text (GTK_ENTRY (gde->date_entry)), "%d/%d/%d",
 		&tm.tm_mon, &tm.tm_mday, &tm.tm_year); /* FIXME: internationalize this - strptime()*/
 
+	tm.tm_mon = CLAMP (tm.tm_mon, 1, 12);
+	tm.tm_mday = CLAMP (tm.tm_mday, 1, 31);
+
 	tm.tm_mon--;
 
 	/* Hope the user does not actually mean years early in the A.D. days...
